package com.zbf.system.service;

import java.util.List;
import com.zbf.system.domain.TErrorLog;

/**
 * agv报警信息Service接口
 *
 * @author tony
 * @date 2024-06-17
 */
public interface ITErrorLogService
{
    /**
     * 查询agv报警信息
     *
     * @param id agv报警信息主键
     * @return agv报警信息
     */
    public TErrorLog selectTErrorLogById(Long id);

    /**
     * 查询agv报警信息列表
     *
     * @param tErrorLog agv报警信息
     * @return agv报警信息集合
     */
    public List<TErrorLog> selectTErrorLogList(TErrorLog tErrorLog);

    /**
     * 新增agv报警信息
     *
     * @param tErrorLog agv报警信息
     * @return 结果
     */
    public int insertTErrorLog(TErrorLog tErrorLog);

    /**
     * 修改agv报警信息
     *
     * @param tErrorLog agv报警信息
     * @return 结果
     */
    public int updateTErrorLog(TErrorLog tErrorLog);

    /**
     * 批量删除agv报警信息
     *
     * @param ids 需要删除的agv报警信息主键集合
     * @return 结果
     */
    public int deleteTErrorLogByIds(Long[] ids);

    /**
     * 删除agv报警信息信息
     *
     * @param id agv报警信息主键
     * @return 结果
     */
    public int deleteTErrorLogById(Long id);

    /**
     * 批量禁用agv报警信息
     *
     * @param ids 需要禁用的agv报警信息主键集合
     * @return 结果
     */
    public int disabledTErrorLogByIds(Long[] ids);

    /**
     * 批量启用agv报警信息
     *
     * @param ids 需要启用的agv报警信息主键集合
     * @return 结果
     */
    public int enableTErrorLogByIds(Long[] ids);

    /**
     * 改变状态
     *
     * @param tErrorLog
     * @return 结果
     */
    public int updateStatus(TErrorLog tErrorLog);
}

